pub type IdentityStoreData = Data<dyn IdentityStore>;Expand description
Convenience extractor for handlers that need the configured identity store.
Aliased Type
pub struct IdentityStoreData(/* private fields */);pub type IdentityStoreData = Data<dyn IdentityStore>;Convenience extractor for handlers that need the configured identity store.
pub struct IdentityStoreData(/* private fields */);